window.Gleam.initSearch([{"doc":"mungo","title":"mungo","content":"![mungo](https://raw.githubusercontent.com/massivefermion/mungo/main/banner.png)\n\n[![Package Version](https://img.shields.io/hexpm/v/mungo)](https://hex.pm/packages/mungo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/mungo/)\n\n# mungo (formerly gleam_mongo)\n&gt; mungo: a felted fabric made from the shredded fibre of repurposed woollen cloth\n---\n\n\nA mongodb driver for gleam\n\n## &lt;img width=32 src=https://raw.githubusercontent.com/massivefermion/mungo/main/icon.png&gt; Quick start\n\n```sh\ngleam shell # Run an Erlang shell\n```\n\n## &lt;img width=32 src=https://raw.githubusercontent.com/massivefermion/mungo/main/icon.png&gt; Installation\n\n```sh\ngleam add mungo\n```\n\n## &lt;img width=32 src=https://raw.githubusercontent.com/massivefermion/mungo/main/icon.png&gt; Roadmap\n\n- [x] support basic mongodb commands\n- [x] support aggregation\n- [x] support connection strings\n- [x] support authentication\n- [x] support mongodb cursors\n- [ ] support connection pooling\n   - The plan is to use [puddle](https://github.com/massivefermion/puddle), but there are still unresolved issues with that package!\n- [ ] support bulk operations\n- [ ] support clusters\n- [ ] support tls\n- [ ] support transactions\n- [ ] support change streams\n- [ ] support other mongodb commands\n\n## &lt;img width=32 src=https://raw.githubusercontent.com/massivefermion/mungo/main/icon.png&gt; Usage\n\n```gleam\nimport gleam/option\nimport mungo\nimport mungo/crud.{Sort, Upsert}\nimport mungo/aggregation.{\n  Let, add_fields, aggregate, match, pipelined_lookup, to_cursor, unwind,\n}\nimport bison/bson\n\npub fn main() {\n  let assert Ok(client) =\n    mungo.start(\n      &quot;mongodb://app-dev:passwd@localhost/app-db?authSource=admin&quot;,\n      512,\n    )\n\n  let users =\n    client\n    |&gt; mungo.collection(&quot;users&quot;)\n\n  let _ =\n    users\n    |&gt; mungo.insert_many(\n      [\n        [\n          #(&quot;username&quot;, bson.String(&quot;jmorrow&quot;)),\n          #(&quot;name&quot;, bson.String(&quot;vincent freeman&quot;)),\n          #(&quot;email&quot;, bson.String(&quot;jmorrow@gattaca.eu&quot;)),\n          #(&quot;age&quot;, bson.Int32(32)),\n        ],\n        [\n          #(&quot;username&quot;, bson.String(&quot;real-jerome&quot;)),\n          #(&quot;name&quot;, bson.String(&quot;jerome eugene morrow&quot;)),\n          #(&quot;email&quot;, bson.String(&quot;real-jerome@running.at&quot;)),\n          #(&quot;age&quot;, bson.Int32(32)),\n        ],\n      ],\n      128,\n    )\n\n  let _ =\n    users\n    |&gt; mungo.update_one(\n      [#(&quot;username&quot;, bson.String(&quot;real-jerome&quot;))],\n      [\n        #(\n          &quot;$set&quot;,\n          bson.Document([\n            #(&quot;username&quot;, bson.String(&quot;eugene&quot;)),\n            #(&quot;email&quot;, bson.String(&quot;eugene@running.at &quot;)),\n          ]),\n        ),\n      ],\n      [Upsert],\n      128,\n    )\n\n  let assert Ok(yahoo_cursor) =\n    users\n    |&gt; mungo.find_many(\n      [#(&quot;email&quot;, bson.Regex(#(&quot;yahoo&quot;, &quot;&quot;)))],\n      [Sort([#(&quot;username&quot;, bson.Int32(-1))])],\n      128,\n    )\n  let _yahoo_users = mungo.to_list(yahoo_cursor, 128)\n\n  let assert Ok(underage_lindsey_cursor) =\n    users\n    |&gt; aggregate([Let([#(&quot;minimum_age&quot;, bson.Int32(21))])], 128)\n    |&gt; match([\n      #(\n        &quot;$expr&quot;,\n        bson.Document([\n          #(\n            &quot;$lt&quot;,\n            bson.Array([bson.String(&quot;$age&quot;), bson.String(&quot;$$minimum_age&quot;)]),\n          ),\n        ]),\n      ),\n    ])\n    |&gt; add_fields([\n      #(\n        &quot;first_name&quot;,\n        bson.Document([\n          #(\n            &quot;$arrayElemAt&quot;,\n            bson.Array([\n              bson.Document([\n                #(\n                  &quot;$split&quot;,\n                  bson.Array([bson.String(&quot;$name&quot;), bson.String(&quot; &quot;)]),\n                ),\n              ]),\n              bson.Int32(0),\n            ]),\n          ),\n        ]),\n      ),\n    ])\n    |&gt; match([#(&quot;first_name&quot;, bson.String(&quot;lindsey&quot;))])\n    |&gt; pipelined_lookup(\n      from: &quot;profiles&quot;,\n      define: [#(&quot;user&quot;, bson.String(&quot;$username&quot;))],\n      pipeline: [\n        [\n          #(\n            &quot;$match&quot;,\n            bson.Document([\n              #(\n                &quot;$expr&quot;,\n                bson.Document([\n                  #(\n                    &quot;$eq&quot;,\n                    bson.Array([bson.String(&quot;$username&quot;), bson.String(&quot;$$user&quot;)]),\n                  ),\n                ]),\n              ),\n            ]),\n          ),\n        ],\n      ],\n      alias: &quot;profile&quot;,\n    )\n    |&gt; unwind(&quot;$profile&quot;, False)\n    |&gt; to_cursor\n\n  let assert #(option.Some(_underage_lindsey), underage_lindsey_cursor) =\n    underage_lindsey_cursor\n    |&gt; mungo.next(128)\n\n  let assert #(option.None, _) =\n    underage_lindsey_cursor\n    |&gt; mungo.next(128)\n}\n```\n","url":"index.html"},{"doc":"mungo/error","title":"Error","content":"pub type Error {\n  StructureError\n  AuthenticationError\n  ActorError\n  TCPError(mug.Error)\n  ConnectionStringError\n  WriteErrors(List(WriteError))\n  ServerError(MongoServerError)\n}\n\nStructureError\n\n\nAuthenticationError\n\n\nActorError\n\n\nTCPError(mug.Error)\n\n\nConnectionStringError\n\n\nWriteErrors(List(WriteError))\n\n\nServerError(MongoServerError)\n\n\nSynonyms:\nmungo/error.Error\nmungo/error Error","url":"mungo/error.html#Error"},{"doc":"mungo/error","title":"MongoServerError","content":"pub type MongoServerError {\n  OK(String)\n  InternalError(String)\n  BadValue(String)\n  NoSuchKey(String)\n  GraphContainsCycle(String)\n  HostUnreachable(String)\n  HostNotFound(String)\n  UnknownError(String)\n  FailedToParse(String)\n  CannotMutateObject(String)\n  UserNotFound(String)\n  UnsupportedFormat(String)\n  Unauthorized(String)\n  TypeMismatch(String)\n  Overflow(String)\n  InvalidLength(String)\n  ProtocolError(String)\n  AuthenticationFailed(String)\n  CannotReuseObject(String)\n  IllegalOperation(String)\n  EmptyArrayOperation(String)\n  InvalidBSON(String)\n  AlreadyInitialized(String)\n  LockTimeout(String)\n  RemoteValidationError(String)\n  NamespaceNotFound(String)\n  IndexNotFound(String)\n  PathNotViable(String)\n  NonExistentPath(String)\n  InvalidPath(String)\n  RoleNotFound(String)\n  RolesNotRelated(String)\n  PrivilegeNotFound(String)\n  CannotBackfillArray(String)\n  UserModificationFailed(String)\n  RemoteChangeDetected(String)\n  FileRenameFailed(String)\n  FileNotOpen(String)\n  FileStreamFailed(String)\n  ConflictingUpdateOperators(String)\n  FileAlreadyOpen(String)\n  LogWriteFailed(String)\n  CursorNotFound(String)\n  UserDataInconsistent(String)\n  LockBusy(String)\n  NoMatchingDocument(String)\n  NamespaceExists(String)\n  InvalidRoleModification(String)\n  MaxTimeMSExpired(String)\n  ManualInterventionRequired(String)\n  DollarPrefixedFieldName(String)\n  InvalidIdField(String)\n  NotSingleValueField(String)\n  InvalidDBRef(String)\n  EmptyFieldName(String)\n  DottedFieldName(String)\n  RoleModificationFailed(String)\n  CommandNotFound(String)\n  ShardKeyNotFound(String)\n  OplogOperationUnsupported(String)\n  StaleShardVersion(String)\n  WriteConcernFailed(String)\n  MultipleErrorsOccurred(String)\n  ImmutableField(String)\n  CannotCreateIndex(String)\n  IndexAlreadyExists(String)\n  AuthSchemaIncompatible(String)\n  ShardNotFound(String)\n  ReplicaSetNotFound(String)\n  InvalidOptions(String)\n  InvalidNamespace(String)\n  NodeNotFound(String)\n  WriteConcernLegacyOK(String)\n  NoReplicationEnabled(String)\n  OperationIncomplete(String)\n  CommandResultSchemaViolation(String)\n  UnknownReplWriteConcern(String)\n  RoleDataInconsistent(String)\n  NoMatchParseContext(String)\n  NoProgressMade(String)\n  RemoteResultsUnavailable(String)\n  IndexOptionsConflict(String)\n  IndexKeySpecsConflict(String)\n  CannotSplit(String)\n  NetworkTimeout(String)\n  CallbackCanceled(String)\n  ShutdownInProgress(String)\n  SecondaryAheadOfPrimary(String)\n  InvalidReplicaSetConfig(String)\n  NotYetInitialized(String)\n  NotSecondary(String)\n  OperationFailed(String)\n  NoProjectionFound(String)\n  DBPathInUse(String)\n  UnsatisfiableWriteConcern(String)\n  OutdatedClient(String)\n  IncompatibleAuditMetadata(String)\n  NewReplicaSetConfigurationIncompatible(String)\n  NodeNotElectable(String)\n  IncompatibleShardingMetadata(String)\n  DistributedClockSkewed(String)\n  LockFailed(String)\n  InconsistentReplicaSetNames(String)\n  ConfigurationInProgress(String)\n  CannotInitializeNodeWithData(String)\n  NotExactValueField(String)\n  WriteConflict(String)\n  InitialSyncFailure(String)\n  InitialSyncOplogSourceMissing(String)\n  CommandNotSupported(String)\n  DocTooLargeForCapped(String)\n  ConflictingOperationInProgress(String)\n  NamespaceNotSharded(String)\n  InvalidSyncSource(String)\n  OplogStartMissing(String)\n  DocumentValidationFailure(String)\n  NotAReplicaSet(String)\n  IncompatibleElectionProtocol(String)\n  CommandFailed(String)\n  RPCProtocolNegotiationFailed(String)\n  UnrecoverableRollbackError(String)\n  LockNotFound(String)\n  LockStateChangeFailed(String)\n  SymbolNotFound(String)\n  FailedToSatisfyReadPreference(String)\n  ReadConcernMajorityNotAvailableYet(String)\n  StaleTerm(String)\n  CappedPositionLost(String)\n  IncompatibleShardingConfigVersion(String)\n  RemoteOplogStale(String)\n  JSInterpreterFailure(String)\n  InvalidSSLConfiguration(String)\n  SSLHandshakeFailed(String)\n  JSUncatchableError(String)\n  CursorInUse(String)\n  IncompatibleCatalogManager(String)\n  PooledConnectionsDropped(String)\n  ExceededMemoryLimit(String)\n  ZLibError(String)\n  ReadConcernMajorityNotEnabled(String)\n  NoConfigPrimary(String)\n  StaleEpoch(String)\n  OperationCannotBeBatched(String)\n  OplogOutOfOrder(String)\n  ChunkTooBig(String)\n  InconsistentShardIdentity(String)\n  CannotApplyOplogWhilePrimary(String)\n  CanRepairToDowngrade(String)\n  MustUpgrade(String)\n  DurationOverflow(String)\n  MaxStalenessOutOfRange(String)\n  IncompatibleCollationVersion(String)\n  CollectionIsEmpty(String)\n  ZoneStillInUse(String)\n  InitialSyncActive(String)\n  ViewDepthLimitExceeded(String)\n  CommandNotSupportedOnView(String)\n  OptionNotSupportedOnView(String)\n  InvalidPipelineOperator(String)\n  CommandOnShardedViewNotSupportedOnMongod(String)\n  TooManyMatchingDocuments(String)\n  CannotIndexParallelArrays(String)\n  TransportSessionClosed(String)\n  TransportSessionNotFound(String)\n  TransportSessionUnknown(String)\n  QueryPlanKilled(String)\n  FileOpenFailed(String)\n  ZoneNotFound(String)\n  RangeOverlapConflict(String)\n  WindowsPdhError(String)\n  BadPerfCounterPath(String)\n  AmbiguousIndexKeyPattern(String)\n  InvalidViewDefinition(String)\n  ClientMetadataMissingField(String)\n  ClientMetadataAppNameTooLarge(String)\n  ClientMetadataDocumentTooLarge(String)\n  ClientMetadataCannotBeMutated(String)\n  LinearizableReadConcernError(String)\n  IncompatibleServerVersion(String)\n  PrimarySteppedDown(String)\n  MasterSlaveConnectionFailure(String)\n  FailPointEnabled(String)\n  NoShardingEnabled(String)\n  BalancerInterrupted(String)\n  ViewPipelineMaxSizeExceeded(String)\n  InvalidIndexSpecificationOption(String)\n  ReplicaSetMonitorRemoved(String)\n  ChunkRangeCleanupPending(String)\n  CannotBuildIndexKeys(String)\n  NetworkInterfaceExceededTimeLimit(String)\n  ShardingStateNotInitialized(String)\n  TimeProofMismatch(String)\n  ClusterTimeFailsRateLimiter(String)\n  NoSuchSession(String)\n  InvalidUUID(String)\n  TooManyLocks(String)\n  StaleClusterTime(String)\n  CannotVerifyAndSignLogicalTime(String)\n  KeyNotFound(String)\n  IncompatibleRollbackAlgorithm(String)\n  DuplicateSession(String)\n  AuthenticationRestrictionUnmet(String)\n  DatabaseDropPending(String)\n  ElectionInProgress(String)\n  IncompleteTransactionHistory(String)\n  UpdateOperationFailed(String)\n  FTDCPathNotSet(String)\n  FTDCPathAlreadySet(String)\n  IndexModified(String)\n  CloseChangeStream(String)\n  IllegalOpMsgFlag(String)\n  QueryFeatureNotAllowed(String)\n  TransactionTooOld(String)\n  AtomicityFailure(String)\n  CannotImplicitlyCreateCollection(String)\n  SessionTransferIncomplete(String)\n  MustDowngrade(String)\n  DNSHostNotFound(String)\n  DNSProtocolError(String)\n  MaxSubPipelineDepthExceeded(String)\n  TooManyDocumentSequences(String)\n  RetryChangeStream(String)\n  InternalErrorNotSupported(String)\n  ForTestingErrorExtraInfo(String)\n  CursorKilled(String)\n  NotImplemented(String)\n  SnapshotTooOld(String)\n  DNSRecordTypeMismatch(String)\n  ConversionFailure(String)\n  CannotCreateCollection(String)\n  IncompatibleWithUpgradedServer(String)\n  BrokenPromise(String)\n  SnapshotUnavailable(String)\n  ProducerConsumerQueueBatchTooLarge(String)\n  ProducerConsumerQueueEndClosed(String)\n  StaleDbVersion(String)\n  StaleChunkHistory(String)\n  NoSuchTransaction(String)\n  ReentrancyNotAllowed(String)\n  FreeMonHttpInFlight(String)\n  FreeMonHttpTemporaryFailure(String)\n  FreeMonHttpPermanentFailure(String)\n  TransactionCommitted(String)\n  TransactionTooLarge(String)\n  UnknownFeatureCompatibilityVersion(String)\n  KeyedExecutorRetry(String)\n  InvalidResumeToken(String)\n  TooManyLogicalSessions(String)\n  ExceededTimeLimit(String)\n  OperationNotSupportedInTransaction(String)\n  TooManyFilesOpen(String)\n  OrphanedRangeCleanUpFailed(String)\n  FailPointSetFailed(String)\n  PreparedTransactionInProgress(String)\n  CannotBackup(String)\n  DataModifiedByRepair(String)\n  RepairedReplicaSetNode(String)\n  JSInterpreterFailureWithStack(String)\n  MigrationConflict(String)\n  ProducerConsumerQueueProducerQueueDepthExceeded(String)\n  ProducerConsumerQueueConsumed(String)\n  ExchangePassthrough(String)\n  IndexBuildAborted(String)\n  AlarmAlreadyFulfilled(String)\n  UnsatisfiableCommitQuorum(String)\n  ClientDisconnect(String)\n  ChangeStreamFatalError(String)\n  TransactionCoordinatorSteppingDown(String)\n  TransactionCoordinatorReachedAbortDecision(String)\n  WouldChangeOwningShard(String)\n  ForTestingErrorExtraInfoWithExtraInfoInNamespace(String)\n  IndexBuildAlreadyInProgress(String)\n  ChangeStreamHistoryLost(String)\n  TransactionCoordinatorDeadlineTaskCanceled(String)\n  ChecksumMismatch(String)\n  WaitForMajorityServiceEarlierOpTimeAvailable(String)\n  TransactionExceededLifetimeLimitSeconds(String)\n  NoQueryExecutionPlans(String)\n  QueryExceededMemoryLimitNoDiskUseAllowed(String)\n  InvalidSeedList(String)\n  InvalidTopologyType(String)\n  InvalidHeartBeatFrequency(String)\n  TopologySetNameRequired(String)\n  HierarchicalAcquisitionLevelViolation(String)\n  InvalidServerType(String)\n  OCSPCertificateStatusRevoked(String)\n  RangeDeletionAbandonedBecauseCollectionWithUUIDDoesNotExist(\n    String,\n  )\n  DataCorruptionDetected(String)\n  OCSPCertificateStatusUnknown(String)\n  SplitHorizonChange(String)\n  ShardInvalidatedForTargeting(String)\n  ReadThroughCacheLookupCanceled(String)\n  RangeDeletionAbandonedBecauseTaskDocumentDoesNotExist(String)\n  CurrentConfigNotCommittedYet(String)\n  ExhaustCommandFinished(String)\n  PeriodicJobIsStopped(String)\n  TransactionCoordinatorCanceled(String)\n  OperationIsKilledAndDelisted(String)\n  ResumableRangeDeleterDisabled(String)\n  ObjectIsBusy(String)\n  TooStaleToSyncFromSource(String)\n  QueryTrialRunCompleted(String)\n  ConnectionPoolExpired(String)\n  ForTestingOptionalErrorExtraInfo(String)\n  MovePrimaryInProgress(String)\n  TenantMigrationConflict(String)\n  TenantMigrationCommitted(String)\n  APIVersionError(String)\n  APIStrictError(String)\n  APIDeprecationError(String)\n  TenantMigrationAborted(String)\n  OplogQueryMinTsMissing(String)\n  NoSuchTenantMigration(String)\n  TenantMigrationAccessBlockerShuttingDown(String)\n  TenantMigrationInProgress(String)\n  SkipCommandExecution(String)\n  FailedToRunWithReplyBuilder(String)\n  CannotDowngrade(String)\n  ServiceExecutorInShutdown(String)\n  MechanismUnavailable(String)\n  TenantMigrationForgotten(String)\n  SocketException(String)\n  CannotGrowDocumentInCappedNamespace(String)\n  NotWritablePrimary(String)\n  BSONObjectTooLarge(String)\n  DuplicateKey(String)\n  InterruptedAtShutdown(String)\n  Interrupted(String)\n  InterruptedDueToReplStateChange(String)\n  BackgroundOperationInProgressForDatabase(String)\n  BackgroundOperationInProgressForNamespace(String)\n  MergeStageNoMatchingDocument(String)\n  DatabaseDifferCase(String)\n  StaleConfig(String)\n  NotPrimaryNoSecondaryOk(String)\n  NotPrimaryOrSecondary(String)\n  OutOfDiskSpace(String)\n  ClientMarkedKilled(String)\n}\n https://github.com/mongodb/mongo/blob/master/src/mongo/base/error_codes.yml\nOK(String)\n\n\nInternalError(String)\n\n\nBadValue(String)\n\n\nNoSuchKey(String)\n\n\nGraphContainsCycle(String)\n\n\nHostUnreachable(String)\n\n\nHostNotFound(String)\n\n\nUnknownError(String)\n\n\nFailedToParse(String)\n\n\nCannotMutateObject(String)\n\n\nUserNotFound(String)\n\n\nUnsupportedFormat(String)\n\n\nUnauthorized(String)\n\n\nTypeMismatch(String)\n\n\nOverflow(String)\n\n\nInvalidLength(String)\n\n\nProtocolError(String)\n\n\nAuthenticationFailed(String)\n\n\nCannotReuseObject(String)\n\n\nIllegalOperation(String)\n\n\nEmptyArrayOperation(String)\n\n\nInvalidBSON(String)\n\n\nAlreadyInitialized(String)\n\n\nLockTimeout(String)\n\n\nRemoteValidationError(String)\n\n\nNamespaceNotFound(String)\n\n\nIndexNotFound(String)\n\n\nPathNotViable(String)\n\n\nNonExistentPath(String)\n\n\nInvalidPath(String)\n\n\nRoleNotFound(String)\n\n\nRolesNotRelated(String)\n\n\nPrivilegeNotFound(String)\n\n\nCannotBackfillArray(String)\n\n\nUserModificationFailed(String)\n\n\nRemoteChangeDetected(String)\n\n\nFileRenameFailed(String)\n\n\nFileNotOpen(String)\n\n\nFileStreamFailed(String)\n\n\nConflictingUpdateOperators(String)\n\n\nFileAlreadyOpen(String)\n\n\nLogWriteFailed(String)\n\n\nCursorNotFound(String)\n\n\nUserDataInconsistent(String)\n\n\nLockBusy(String)\n\n\nNoMatchingDocument(String)\n\n\nNamespaceExists(String)\n\n\nInvalidRoleModification(String)\n\n\nMaxTimeMSExpired(String)\n\n\nManualInterventionRequired(String)\n\n\nDollarPrefixedFieldName(String)\n\n\nInvalidIdField(String)\n\n\nNotSingleValueField(String)\n\n\nInvalidDBRef(String)\n\n\nEmptyFieldName(String)\n\n\nDottedFieldName(String)\n\n\nRoleModificationFailed(String)\n\n\nCommandNotFound(String)\n\n\nShardKeyNotFound(String)\n\n\nOplogOperationUnsupported(String)\n\n\nStaleShardVersion(String)\n\n\nWriteConcernFailed(String)\n\n\nMultipleErrorsOccurred(String)\n\n\nImmutableField(String)\n\n\nCannotCreateIndex(String)\n\n\nIndexAlreadyExists(String)\n\n\nAuthSchemaIncompatible(String)\n\n\nShardNotFound(String)\n\n\nReplicaSetNotFound(String)\n\n\nInvalidOptions(String)\n\n\nInvalidNamespace(String)\n\n\nNodeNotFound(String)\n\n\nWriteConcernLegacyOK(String)\n\n\nNoReplicationEnabled(String)\n\n\nOperationIncomplete(String)\n\n\nCommandResultSchemaViolation(String)\n\n\nUnknownReplWriteConcern(String)\n\n\nRoleDataInconsistent(String)\n\n\nNoMatchParseContext(String)\n\n\nNoProgressMade(String)\n\n\nRemoteResultsUnavailable(String)\n\n\nIndexOptionsConflict(String)\n\n\nIndexKeySpecsConflict(String)\n\n\nCannotSplit(String)\n\n\nNetworkTimeout(String)\n\n\nCallbackCanceled(String)\n\n\nShutdownInProgress(String)\n\n\nSecondaryAheadOfPrimary(String)\n\n\nInvalidReplicaSetConfig(String)\n\n\nNotYetInitialized(String)\n\n\nNotSecondary(String)\n\n\nOperationFailed(String)\n\n\nNoProjectionFound(String)\n\n\nDBPathInUse(String)\n\n\nUnsatisfiableWriteConcern(String)\n\n\nOutdatedClient(String)\n\n\nIncompatibleAuditMetadata(String)\n\n\nNewReplicaSetConfigurationIncompatible(String)\n\n\nNodeNotElectable(String)\n\n\nIncompatibleShardingMetadata(String)\n\n\nDistributedClockSkewed(String)\n\n\nLockFailed(String)\n\n\nInconsistentReplicaSetNames(String)\n\n\nConfigurationInProgress(String)\n\n\nCannotInitializeNodeWithData(String)\n\n\nNotExactValueField(String)\n\n\nWriteConflict(String)\n\n\nInitialSyncFailure(String)\n\n\nInitialSyncOplogSourceMissing(String)\n\n\nCommandNotSupported(String)\n\n\nDocTooLargeForCapped(String)\n\n\nConflictingOperationInProgress(String)\n\n\nNamespaceNotSharded(String)\n\n\nInvalidSyncSource(String)\n\n\nOplogStartMissing(String)\n\n\nDocumentValidationFailure(String)\n\n\nNotAReplicaSet(String)\n\n\nIncompatibleElectionProtocol(String)\n\n\nCommandFailed(String)\n\n\nRPCProtocolNegotiationFailed(String)\n\n\nUnrecoverableRollbackError(String)\n\n\nLockNotFound(String)\n\n\nLockStateChangeFailed(String)\n\n\nSymbolNotFound(String)\n\n\nFailedToSatisfyReadPreference(String)\n\n\nReadConcernMajorityNotAvailableYet(String)\n\n\nStaleTerm(String)\n\n\nCappedPositionLost(String)\n\n\nIncompatibleShardingConfigVersion(String)\n\n\nRemoteOplogStale(String)\n\n\nJSInterpreterFailure(String)\n\n\nInvalidSSLConfiguration(String)\n\n\nSSLHandshakeFailed(String)\n\n\nJSUncatchableError(String)\n\n\nCursorInUse(String)\n\n\nIncompatibleCatalogManager(String)\n\n\nPooledConnectionsDropped(String)\n\n\nExceededMemoryLimit(String)\n\n\nZLibError(String)\n\n\nReadConcernMajorityNotEnabled(String)\n\n\nNoConfigPrimary(String)\n\n\nStaleEpoch(String)\n\n\nOperationCannotBeBatched(String)\n\n\nOplogOutOfOrder(String)\n\n\nChunkTooBig(String)\n\n\nInconsistentShardIdentity(String)\n\n\nCannotApplyOplogWhilePrimary(String)\n\n\nCanRepairToDowngrade(String)\n\n\nMustUpgrade(String)\n\n\nDurationOverflow(String)\n\n\nMaxStalenessOutOfRange(String)\n\n\nIncompatibleCollationVersion(String)\n\n\nCollectionIsEmpty(String)\n\n\nZoneStillInUse(String)\n\n\nInitialSyncActive(String)\n\n\nViewDepthLimitExceeded(String)\n\n\nCommandNotSupportedOnView(String)\n\n\nOptionNotSupportedOnView(String)\n\n\nInvalidPipelineOperator(String)\n\n\nCommandOnShardedViewNotSupportedOnMongod(String)\n\n\nTooManyMatchingDocuments(String)\n\n\nCannotIndexParallelArrays(String)\n\n\nTransportSessionClosed(String)\n\n\nTransportSessionNotFound(String)\n\n\nTransportSessionUnknown(String)\n\n\nQueryPlanKilled(String)\n\n\nFileOpenFailed(String)\n\n\nZoneNotFound(String)\n\n\nRangeOverlapConflict(String)\n\n\nWindowsPdhError(String)\n\n\nBadPerfCounterPath(String)\n\n\nAmbiguousIndexKeyPattern(String)\n\n\nInvalidViewDefinition(String)\n\n\nClientMetadataMissingField(String)\n\n\nClientMetadataAppNameTooLarge(String)\n\n\nClientMetadataDocumentTooLarge(String)\n\n\nClientMetadataCannotBeMutated(String)\n\n\nLinearizableReadConcernError(String)\n\n\nIncompatibleServerVersion(String)\n\n\nPrimarySteppedDown(String)\n\n\nMasterSlaveConnectionFailure(String)\n\n\nFailPointEnabled(String)\n\n\nNoShardingEnabled(String)\n\n\nBalancerInterrupted(String)\n\n\nViewPipelineMaxSizeExceeded(String)\n\n\nInvalidIndexSpecificationOption(String)\n\n\nReplicaSetMonitorRemoved(String)\n\n\nChunkRangeCleanupPending(String)\n\n\nCannotBuildIndexKeys(String)\n\n\nNetworkInterfaceExceededTimeLimit(String)\n\n\nShardingStateNotInitialized(String)\n\n\nTimeProofMismatch(String)\n\n\nClusterTimeFailsRateLimiter(String)\n\n\nNoSuchSession(String)\n\n\nInvalidUUID(String)\n\n\nTooManyLocks(String)\n\n\nStaleClusterTime(String)\n\n\nCannotVerifyAndSignLogicalTime(String)\n\n\nKeyNotFound(String)\n\n\nIncompatibleRollbackAlgorithm(String)\n\n\nDuplicateSession(String)\n\n\nAuthenticationRestrictionUnmet(String)\n\n\nDatabaseDropPending(String)\n\n\nElectionInProgress(String)\n\n\nIncompleteTransactionHistory(String)\n\n\nUpdateOperationFailed(String)\n\n\nFTDCPathNotSet(String)\n\n\nFTDCPathAlreadySet(String)\n\n\nIndexModified(String)\n\n\nCloseChangeStream(String)\n\n\nIllegalOpMsgFlag(String)\n\n\nQueryFeatureNotAllowed(String)\n\n\nTransactionTooOld(String)\n\n\nAtomicityFailure(String)\n\n\nCannotImplicitlyCreateCollection(String)\n\n\nSessionTransferIncomplete(String)\n\n\nMustDowngrade(String)\n\n\nDNSHostNotFound(String)\n\n\nDNSProtocolError(String)\n\n\nMaxSubPipelineDepthExceeded(String)\n\n\nTooManyDocumentSequences(String)\n\n\nRetryChangeStream(String)\n\n\nInternalErrorNotSupported(String)\n\n\nForTestingErrorExtraInfo(String)\n\n\nCursorKilled(String)\n\n\nNotImplemented(String)\n\n\nSnapshotTooOld(String)\n\n\nDNSRecordTypeMismatch(String)\n\n\nConversionFailure(String)\n\n\nCannotCreateCollection(String)\n\n\nIncompatibleWithUpgradedServer(String)\n\n\nBrokenPromise(String)\n\n\nSnapshotUnavailable(String)\n\n\nProducerConsumerQueueBatchTooLarge(String)\n\n\nProducerConsumerQueueEndClosed(String)\n\n\nStaleDbVersion(String)\n\n\nStaleChunkHistory(String)\n\n\nNoSuchTransaction(String)\n\n\nReentrancyNotAllowed(String)\n\n\nFreeMonHttpInFlight(String)\n\n\nFreeMonHttpTemporaryFailure(String)\n\n\nFreeMonHttpPermanentFailure(String)\n\n\nTransactionCommitted(String)\n\n\nTransactionTooLarge(String)\n\n\nUnknownFeatureCompatibilityVersion(String)\n\n\nKeyedExecutorRetry(String)\n\n\nInvalidResumeToken(String)\n\n\nTooManyLogicalSessions(String)\n\n\nExceededTimeLimit(String)\n\n\nOperationNotSupportedInTransaction(String)\n\n\nTooManyFilesOpen(String)\n\n\nOrphanedRangeCleanUpFailed(String)\n\n\nFailPointSetFailed(String)\n\n\nPreparedTransactionInProgress(String)\n\n\nCannotBackup(String)\n\n\nDataModifiedByRepair(String)\n\n\nRepairedReplicaSetNode(String)\n\n\nJSInterpreterFailureWithStack(String)\n\n\nMigrationConflict(String)\n\n\nProducerConsumerQueueProducerQueueDepthExceeded(String)\n\n\nProducerConsumerQueueConsumed(String)\n\n\nExchangePassthrough(String)\n\n\nIndexBuildAborted(String)\n\n\nAlarmAlreadyFulfilled(String)\n\n\nUnsatisfiableCommitQuorum(String)\n\n\nClientDisconnect(String)\n\n\nChangeStreamFatalError(String)\n\n\nTransactionCoordinatorSteppingDown(String)\n\n\nTransactionCoordinatorReachedAbortDecision(String)\n\n\nWouldChangeOwningShard(String)\n\n\nForTestingErrorExtraInfoWithExtraInfoInNamespace(String)\n\n\nIndexBuildAlreadyInProgress(String)\n\n\nChangeStreamHistoryLost(String)\n\n\nTransactionCoordinatorDeadlineTaskCanceled(String)\n\n\nChecksumMismatch(String)\n\n\nWaitForMajorityServiceEarlierOpTimeAvailable(String)\n\n\nTransactionExceededLifetimeLimitSeconds(String)\n\n\nNoQueryExecutionPlans(String)\n\n\nQueryExceededMemoryLimitNoDiskUseAllowed(String)\n\n\nInvalidSeedList(String)\n\n\nInvalidTopologyType(String)\n\n\nInvalidHeartBeatFrequency(String)\n\n\nTopologySetNameRequired(String)\n\n\nHierarchicalAcquisitionLevelViolation(String)\n\n\nInvalidServerType(String)\n\n\nOCSPCertificateStatusRevoked(String)\n\n\nRangeDeletionAbandonedBecauseCollectionWithUUIDDoesNotExist(\n  String,\n)\n\n\nDataCorruptionDetected(String)\n\n\nOCSPCertificateStatusUnknown(String)\n\n\nSplitHorizonChange(String)\n\n\nShardInvalidatedForTargeting(String)\n\n\nReadThroughCacheLookupCanceled(String)\n\n\nRangeDeletionAbandonedBecauseTaskDocumentDoesNotExist(String)\n\n\nCurrentConfigNotCommittedYet(String)\n\n\nExhaustCommandFinished(String)\n\n\nPeriodicJobIsStopped(String)\n\n\nTransactionCoordinatorCanceled(String)\n\n\nOperationIsKilledAndDelisted(String)\n\n\nResumableRangeDeleterDisabled(String)\n\n\nObjectIsBusy(String)\n\n\nTooStaleToSyncFromSource(String)\n\n\nQueryTrialRunCompleted(String)\n\n\nConnectionPoolExpired(String)\n\n\nForTestingOptionalErrorExtraInfo(String)\n\n\nMovePrimaryInProgress(String)\n\n\nTenantMigrationConflict(String)\n\n\nTenantMigrationCommitted(String)\n\n\nAPIVersionError(String)\n\n\nAPIStrictError(String)\n\n\nAPIDeprecationError(String)\n\n\nTenantMigrationAborted(String)\n\n\nOplogQueryMinTsMissing(String)\n\n\nNoSuchTenantMigration(String)\n\n\nTenantMigrationAccessBlockerShuttingDown(String)\n\n\nTenantMigrationInProgress(String)\n\n\nSkipCommandExecution(String)\n\n\nFailedToRunWithReplyBuilder(String)\n\n\nCannotDowngrade(String)\n\n\nServiceExecutorInShutdown(String)\n\n\nMechanismUnavailable(String)\n\n\nTenantMigrationForgotten(String)\n\n\nSocketException(String)\n\n\nCannotGrowDocumentInCappedNamespace(String)\n\n\nNotWritablePrimary(String)\n\n\nBSONObjectTooLarge(String)\n\n\nDuplicateKey(String)\n\n\nInterruptedAtShutdown(String)\n\n\nInterrupted(String)\n\n\nInterruptedDueToReplStateChange(String)\n\n\nBackgroundOperationInProgressForDatabase(String)\n\n\nBackgroundOperationInProgressForNamespace(String)\n\n\nMergeStageNoMatchingDocument(String)\n\n\nDatabaseDifferCase(String)\n\n\nStaleConfig(String)\n\n\nNotPrimaryNoSecondaryOk(String)\n\n\nNotPrimaryOrSecondary(String)\n\n\nOutOfDiskSpace(String)\n\n\nClientMarkedKilled(String)\n\n\nSynonyms:\nmungo/error.MongoServerError\nmungo/error MongoServerError","url":"mungo/error.html#MongoServerError"},{"doc":"mungo/error","title":"WriteError","content":"pub type WriteError {\n  WriteError(Int, String, bson.Value)\n}\n\nWriteError(Int, String, bson.Value)\n\n\nSynonyms:\nmungo/error.WriteError\nmungo/error WriteError","url":"mungo/error.html#WriteError"},{"doc":"mungo/error","title":"code_to_server_error","content":"pub const code_to_server_error: List(\n  #(Int, fn(String) -&gt; MongoServerError),\n)\n\nSynonyms:\nmungo/error.code_to_server_error\nmungo/error code_to_server_error","url":"mungo/error.html#code_to_server_error"},{"doc":"mungo/error","title":"is_not_primary_error","content":"pub fn is_not_primary_error(error: MongoServerError) -&gt; Bool\n\nSynonyms:\nmungo/error.is_not_primary_error\nmungo/error is_not_primary_error","url":"mungo/error.html#is_not_primary_error"},{"doc":"mungo/error","title":"is_retriable_error","content":"pub fn is_retriable_error(error: MongoServerError) -&gt; Bool\n\nSynonyms:\nmungo/error.is_retriable_error\nmungo/error is_retriable_error","url":"mungo/error.html#is_retriable_error"},{"doc":"mungo/error","title":"mungo/error","content":"","url":"mungo/error.html"},{"doc":"mungo/crud","title":"FindOption","content":"pub type FindOption {\n  Skip(Int)\n  Limit(Int)\n  BatchSize(Int)\n  Sort(List(#(String, bson.Value)))\n  Projection(List(#(String, bson.Value)))\n}\n\nSkip(Int)\n\n\nLimit(Int)\n\n\nBatchSize(Int)\n\n\nSort(List(#(String, bson.Value)))\n\n\nProjection(List(#(String, bson.Value)))\n\n\nSynonyms:\nmungo/crud.FindOption\nmungo/crud FindOption","url":"mungo/crud.html#FindOption"},{"doc":"mungo/crud","title":"InsertResult","content":"pub type InsertResult {\n  InsertResult(inserted: Int, inserted_ids: List(bson.Value))\n}\n\nInsertResult(inserted: Int, inserted_ids: List(bson.Value))\n\n\nSynonyms:\nmungo/crud.InsertResult\nmungo/crud InsertResult","url":"mungo/crud.html#InsertResult"},{"doc":"mungo/crud","title":"UpdateOption","content":"pub type UpdateOption {\n  Upsert\n  ArrayFilters(List(List(#(String, bson.Value))))\n}\n\nUpsert\n\n\nArrayFilters(List(List(#(String, bson.Value))))\n\n\nSynonyms:\nmungo/crud.UpdateOption\nmungo/crud UpdateOption","url":"mungo/crud.html#UpdateOption"},{"doc":"mungo/crud","title":"UpdateResult","content":"pub type UpdateResult {\n  UpdateResult(\n    matched: Int,\n    modified: Int,\n    upserted: List(bson.Value),\n  )\n}\n\nUpdateResult(\n  matched: Int,\n  modified: Int,\n  upserted: List(bson.Value),\n)\n\n\nSynonyms:\nmungo/crud.UpdateResult\nmungo/crud UpdateResult","url":"mungo/crud.html#UpdateResult"},{"doc":"mungo/crud","title":"count","content":"pub fn count(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo/crud.count\nmungo/crud count","url":"mungo/crud.html#count"},{"doc":"mungo/crud","title":"count_all","content":"pub fn count_all(\n  collection: Collection,\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo/crud.count_all\nmungo/crud count_all","url":"mungo/crud.html#count_all"},{"doc":"mungo/crud","title":"delete_many","content":"pub fn delete_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo/crud.delete_many\nmungo/crud delete_many","url":"mungo/crud.html#delete_many"},{"doc":"mungo/crud","title":"delete_one","content":"pub fn delete_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo/crud.delete_one\nmungo/crud delete_one","url":"mungo/crud.html#delete_one"},{"doc":"mungo/crud","title":"find_all","content":"pub fn find_all(\n  collection: Collection,\n  options: List(FindOption),\n  timeout: Int,\n) -&gt; Result(Cursor, Error)\n\nSynonyms:\nmungo/crud.find_all\nmungo/crud find_all","url":"mungo/crud.html#find_all"},{"doc":"mungo/crud","title":"find_by_id","content":"pub fn find_by_id(\n  collection: Collection,\n  id: String,\n  timeout: Int,\n) -&gt; Result(Option(Value), Error)\n\nSynonyms:\nmungo/crud.find_by_id\nmungo/crud find_by_id","url":"mungo/crud.html#find_by_id"},{"doc":"mungo/crud","title":"find_many","content":"pub fn find_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  options: List(FindOption),\n  timeout: Int,\n) -&gt; Result(Cursor, Error)\n\nSynonyms:\nmungo/crud.find_many\nmungo/crud find_many","url":"mungo/crud.html#find_many"},{"doc":"mungo/crud","title":"find_one","content":"pub fn find_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  projection: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Option(Value), Error)\n\nSynonyms:\nmungo/crud.find_one\nmungo/crud find_one","url":"mungo/crud.html#find_one"},{"doc":"mungo/crud","title":"insert_many","content":"pub fn insert_many(\n  collection: Collection,\n  docs: List(List(#(String, Value))),\n  timeout: Int,\n) -&gt; Result(InsertResult, Error)\n\nSynonyms:\nmungo/crud.insert_many\nmungo/crud insert_many","url":"mungo/crud.html#insert_many"},{"doc":"mungo/crud","title":"insert_one","content":"pub fn insert_one(\n  collection: Collection,\n  doc: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Value, Error)\n\nSynonyms:\nmungo/crud.insert_one\nmungo/crud insert_one","url":"mungo/crud.html#insert_one"},{"doc":"mungo/crud","title":"update_many","content":"pub fn update_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  change: List(#(String, Value)),\n  options: List(UpdateOption),\n  timeout: Int,\n) -&gt; Result(UpdateResult, Error)\n for more information, see [here](https://www.mongodb.com/docs/manual/reference/operator/update)\nSynonyms:\nmungo/crud.update_many\nmungo/crud update_many","url":"mungo/crud.html#update_many"},{"doc":"mungo/crud","title":"update_one","content":"pub fn update_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  change: List(#(String, Value)),\n  options: List(UpdateOption),\n  timeout: Int,\n) -&gt; Result(UpdateResult, Error)\n for more information, see [here](https://www.mongodb.com/docs/manual/reference/operator/update)\nSynonyms:\nmungo/crud.update_one\nmungo/crud update_one","url":"mungo/crud.html#update_one"},{"doc":"mungo/crud","title":"mungo/crud","content":"","url":"mungo/crud.html"},{"doc":"mungo","title":"Message","content":"pub type Message =\n  client.Message\n\n\nSynonyms:\nmungo.Message\nmungo Message","url":"mungo.html#Message"},{"doc":"mungo","title":"collection","content":"pub fn collection(\n  db: Subject(Message),\n  name: String,\n) -&gt; Collection\n\nSynonyms:\nmungo.collection\nmungo collection","url":"mungo.html#collection"},{"doc":"mungo","title":"count","content":"pub fn count(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo.count\nmungo count","url":"mungo.html#count"},{"doc":"mungo","title":"count_all","content":"pub fn count_all(\n  collection: Collection,\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo.count_all\nmungo count_all","url":"mungo.html#count_all"},{"doc":"mungo","title":"delete_many","content":"pub fn delete_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo.delete_many\nmungo delete_many","url":"mungo.html#delete_many"},{"doc":"mungo","title":"delete_one","content":"pub fn delete_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Int, Error)\n\nSynonyms:\nmungo.delete_one\nmungo delete_one","url":"mungo.html#delete_one"},{"doc":"mungo","title":"find_all","content":"pub fn find_all(\n  collection: Collection,\n  options: List(FindOption),\n  timeout: Int,\n) -&gt; Result(Cursor, Error)\n\nSynonyms:\nmungo.find_all\nmungo find_all","url":"mungo.html#find_all"},{"doc":"mungo","title":"find_by_id","content":"pub fn find_by_id(\n  collection: Collection,\n  id: String,\n  timeout: Int,\n) -&gt; Result(Option(Value), Error)\n\nSynonyms:\nmungo.find_by_id\nmungo find_by_id","url":"mungo.html#find_by_id"},{"doc":"mungo","title":"find_many","content":"pub fn find_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  options: List(FindOption),\n  timeout: Int,\n) -&gt; Result(Cursor, Error)\n\nSynonyms:\nmungo.find_many\nmungo find_many","url":"mungo.html#find_many"},{"doc":"mungo","title":"find_one","content":"pub fn find_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  projection: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Option(Value), Error)\n\nSynonyms:\nmungo.find_one\nmungo find_one","url":"mungo.html#find_one"},{"doc":"mungo","title":"insert_many","content":"pub fn insert_many(\n  collection: Collection,\n  docs: List(List(#(String, Value))),\n  timeout: Int,\n) -&gt; Result(InsertResult, Error)\n\nSynonyms:\nmungo.insert_many\nmungo insert_many","url":"mungo.html#insert_many"},{"doc":"mungo","title":"insert_one","content":"pub fn insert_one(\n  collection: Collection,\n  doc: List(#(String, Value)),\n  timeout: Int,\n) -&gt; Result(Value, Error)\n\nSynonyms:\nmungo.insert_one\nmungo insert_one","url":"mungo.html#insert_one"},{"doc":"mungo","title":"next","content":"pub fn next(\n  cursor: Cursor,\n  timeout: Int,\n) -&gt; #(Option(Value), Cursor)\n\nSynonyms:\nmungo.next\nmungo next","url":"mungo.html#next"},{"doc":"mungo","title":"start","content":"pub fn start(\n  uri: String,\n  timeout: Int,\n) -&gt; Result(Subject(Message), StartError)\n The connection uri must specify the database\nSynonyms:\nmungo.start\nmungo start","url":"mungo.html#start"},{"doc":"mungo","title":"to_list","content":"pub fn to_list(cursor: Cursor, timeout: Int) -&gt; List(Value)\n\nSynonyms:\nmungo.to_list\nmungo to_list","url":"mungo.html#to_list"},{"doc":"mungo","title":"update_many","content":"pub fn update_many(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  change: List(#(String, Value)),\n  options: List(UpdateOption),\n  timeout: Int,\n) -&gt; Result(UpdateResult, Error)\n\nSynonyms:\nmungo.update_many\nmungo update_many","url":"mungo.html#update_many"},{"doc":"mungo","title":"update_one","content":"pub fn update_one(\n  collection: Collection,\n  filter: List(#(String, Value)),\n  change: List(#(String, Value)),\n  options: List(UpdateOption),\n  timeout: Int,\n) -&gt; Result(UpdateResult, Error)\n\nSynonyms:\nmungo.update_one\nmungo update_one","url":"mungo.html#update_one"},{"doc":"mungo","title":"mungo","content":"","url":"mungo.html"},{"doc":"mungo/aggregation","title":"AggregateOption","content":"pub type AggregateOption {\n  BatchSize(Int)\n  Let(List(#(String, bson.Value)))\n}\n\nBatchSize(Int)\n\n\nLet(List(#(String, bson.Value)))\n\n\nSynonyms:\nmungo/aggregation.AggregateOption\nmungo/aggregation AggregateOption","url":"mungo/aggregation.html#AggregateOption"},{"doc":"mungo/aggregation","title":"Pipeline","content":"pub opaque type Pipeline\n\n\nSynonyms:\nmungo/aggregation.Pipeline\nmungo/aggregation Pipeline","url":"mungo/aggregation.html#Pipeline"},{"doc":"mungo/aggregation","title":"add_fields","content":"pub fn add_fields(\n  pipeline: Pipeline,\n  doc: List(#(String, Value)),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.add_fields\nmungo/aggregation add_fields","url":"mungo/aggregation.html#add_fields"},{"doc":"mungo/aggregation","title":"aggregate","content":"pub fn aggregate(\n  collection: Collection,\n  options: List(AggregateOption),\n  timeout: Int,\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.aggregate\nmungo/aggregation aggregate","url":"mungo/aggregation.html#aggregate"},{"doc":"mungo/aggregation","title":"append_stage","content":"pub fn append_stage(\n  pipeline: Pipeline,\n  stage: #(String, Value),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.append_stage\nmungo/aggregation append_stage","url":"mungo/aggregation.html#append_stage"},{"doc":"mungo/aggregation","title":"group","content":"pub fn group(\n  pipeline: Pipeline,\n  doc: List(#(String, Value)),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.group\nmungo/aggregation group","url":"mungo/aggregation.html#group"},{"doc":"mungo/aggregation","title":"limit","content":"pub fn limit(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.limit\nmungo/aggregation limit","url":"mungo/aggregation.html#limit"},{"doc":"mungo/aggregation","title":"lookup","content":"pub fn lookup(\n  pipeline: Pipeline,\n  from from: String,\n  local_field local_field: String,\n  foreign_field foreign_field: String,\n  alias alias: String,\n) -&gt; Pipeline\n for more information, see [here](https://www.mongodb.com/docs/manual/reference/operator/aggregation/lookup)\nSynonyms:\nmungo/aggregation.lookup\nmungo/aggregation lookup","url":"mungo/aggregation.html#lookup"},{"doc":"mungo/aggregation","title":"match","content":"pub fn match(\n  pipeline: Pipeline,\n  doc: List(#(String, Value)),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.match\nmungo/aggregation match","url":"mungo/aggregation.html#match"},{"doc":"mungo/aggregation","title":"pipelined_lookup","content":"pub fn pipelined_lookup(\n  pipeline: Pipeline,\n  from from: String,\n  define definitions: List(#(String, Value)),\n  pipeline lookup_pipeline: List(List(#(String, Value))),\n  alias alias: String,\n) -&gt; Pipeline\n for more information, see [here](https://www.mongodb.com/docs/manual/reference/operator/aggregation/lookup)\nSynonyms:\nmungo/aggregation.pipelined_lookup\nmungo/aggregation pipelined_lookup","url":"mungo/aggregation.html#pipelined_lookup"},{"doc":"mungo/aggregation","title":"project","content":"pub fn project(\n  pipeline: Pipeline,\n  doc: List(#(String, Value)),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.project\nmungo/aggregation project","url":"mungo/aggregation.html#project"},{"doc":"mungo/aggregation","title":"skip","content":"pub fn skip(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.skip\nmungo/aggregation skip","url":"mungo/aggregation.html#skip"},{"doc":"mungo/aggregation","title":"sort","content":"pub fn sort(\n  pipeline: Pipeline,\n  doc: List(#(String, Value)),\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.sort\nmungo/aggregation sort","url":"mungo/aggregation.html#sort"},{"doc":"mungo/aggregation","title":"to_cursor","content":"pub fn to_cursor(pipeline: Pipeline) -&gt; Result(Cursor, Error)\n\nSynonyms:\nmungo/aggregation.to_cursor\nmungo/aggregation to_cursor","url":"mungo/aggregation.html#to_cursor"},{"doc":"mungo/aggregation","title":"unwind","content":"pub fn unwind(\n  pipeline: Pipeline,\n  path: String,\n  preserve_null_and_empty_arrays: Bool,\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.unwind\nmungo/aggregation unwind","url":"mungo/aggregation.html#unwind"},{"doc":"mungo/aggregation","title":"unwind_with_index","content":"pub fn unwind_with_index(\n  pipeline: Pipeline,\n  path: String,\n  index_field: String,\n  preserve_null_and_empty_arrays: Bool,\n) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.unwind_with_index\nmungo/aggregation unwind_with_index","url":"mungo/aggregation.html#unwind_with_index"},{"doc":"mungo/aggregation","title":"mungo/aggregation","content":" for more information, see [here](https://www.mongodb.com/docs/manual/reference/operator/aggregation-pipeline)","url":"mungo/aggregation.html"}]);